import io
import os
import ParagraphExtractor as pe
from bs4 import BeautifulSoup

# replacements for some of the special characters
replacements = {
            r'\xfc': 'ue',
            r'\xdf': 'ss',
            r'\xf6': 'oe',
            r'\xe4': 'ae',
            r'\n': '',
            r'\xa0': '',
            r'\xdc': 'Ue',
            r'\xd6': 'Oe',
            r'\u201': '',
            r'\xc4': 'Ae',
            r'\t': '',
            r'\r': '',
            r'\r\n': '',
            r'\u20ac': '€',
            r'xe9': 'e',
            r'\xe0': 'a',
            r'\xe8': 'e',
            r'\u2026': '',
            r'\xe1': 'a',
            r'\xd7': 'x',
            r'\xd4': 'o',
            r'\xe3': 'a',
            r'\xeb': 'e',
            r'\xc9': 'E',
            r'\xbb': '',
            r'\xab': '',
            r'\xb4': '',
            r'\u2028': '',
            r'\xed': 'i',
            r'\xad': '',
            r'\xf8': 'oe',
            r'\xf3': 'o',
            r'\xf4': 'o',
            r'\xe7': 'c',
            r'\xa7': '',
            '\\': ''
        }


def read_csv(file):
    with io.open('articles/'+file, encoding='utf-8') as websites:
        lines = websites.readlines()
        clean_lines = []

        # fix quotation in the website downloads so the processing works
        for line in lines:
            clean_line = line.replace('""', '\"')
            clean_lines.append(clean_line)
        # remove new lines (\n)
        articles = list(filter(lambda x: x != '\n', clean_lines))
        print('Finished reading file. {} articles were found.'.format(len(articles)))
        return articles

def write_to_file(lines):
    # extract and write articles to file iteratively
    for x in range(0, len(lines)):
        website_download = lines[x]
        soup = BeautifulSoup(website_download, 'html.parser')

        full_url = website_download.split('","')[2]
        article_info = full_url.split('/')
        url = article_info[2]

        # article extraction
        result = None
        site = ''
        if 'faz.net' in url:
            result = pe.faz(soup)
            site = 'faz'
        elif 'focus.de' in url:
            result = pe.focus(soup)
            site = 'focus'
        elif 'spiegel.de' in url:
            result = pe.spiegel(soup)
            site = 'spiegel'
        elif 'sueddeutsche.de' in url:
            result = pe.sueddeutsche(soup)
            site = 'sueddeutsche'
        elif 'tagesschau.de' in url:
            result = pe.tagesschau(soup)
            site = 'tagesschau'
        elif 't-online.de' in url:
            result = pe.tonline(soup)
            site = 'tonline'
        elif 'welt.de' in url:
            result = pe.welt(soup)
            site = 'welt'
        elif 'zdf.de' in url:
            result = pe.zdf(soup)
            site = 'zdf'
        elif 'zeit.de' in url:
            result = pe.zeit(soup)
            site = 'zeit'

        output_file = 'test_articles/{}.txt'.format(site)

        # check if the article/result is not None and has more than 50 characters
        # (filters some articles that just have a video or image gallery but no text)
        if result is not None and len(result) > 50:
            # replace all the special characters iteratively
            for i, j in replacements.items():
                result = result.replace(i, j)

            # write to file
            with io.open(output_file, 'a', encoding='utf-8') as txt_file:
                txt_file.write(result+'\n')
    print('Finished extracting data.')
    print('--------------------------')

if __name__ == '__main__':
    for file in os.listdir('articles/'):
        articles = read_csv(file)

        urls = []
        content = []
        # removes duplicates by comparing article URLS
        for article in articles:
            if article.split('","')[2] not in urls:
                content.append(article)
            urls.append(article.split('","')[2])

        write_to_file(content)
