# each of the functions uses the given BS4 soup to get the article's text by accessing the corresponding HTML-tags
# these HTML-tags can be different for the 9 sites
# once the article is found, the paragraphs are put into a list and then joined/concatenated and returned
# if no article is found, None is returned

def focus(soup):
    article = soup.find(id='article')
    if article is None:
        return None
    else:
        paragraphs = article.find_all('p')
        content_list = []
        for paragraph in paragraphs:
            content_list.append(paragraph.get_text().strip())
        content = ' '.join(content_list)
        return content

def faz(soup):
    content_list = []
    paragraphs = soup.find_all('p', attrs={'class': 'atc-TextParagraph'})
    for paragraph in paragraphs:
        content_list.append(paragraph.text.strip())
    content = ' '.join(content_list)
    return content

def spiegel(soup):
    paragraph_div = soup.find('div', attrs={'class': 'article-section clearfix'})
    if paragraph_div is None:
        return None
    else:
        paragraphs = paragraph_div.find_all('p')
        content_list = []
        for paragraph in paragraphs:
            if not paragraph.has_attr('lang') and not paragraph.has_attr('style'):
                content_list.append(paragraph.get_text().strip())
        content = ' '.join(content_list)
        return content

def sueddeutsche(soup):
    if soup.article is not None:
        paragraphs = soup.article.find_all('p')
        content_list = []
        for paragraph in paragraphs:
            content_list.append(paragraph.get_text().strip())
        content = ' '.join(content_list)
        return content
    else:
        return None

def tagesschau(soup):
    paragraph_div = soup.find('div', attrs={'class': 'section sectionZ sectionArticle'})
    if paragraph_div is not None:
        paragraphs = paragraph_div.find_all('p', attrs={'class': 'text small'})
        content_list = []
        for paragraph in paragraphs:
            content_list.append(paragraph.get_text().strip())
        content = ' '.join(content_list)
        return content
    else:
        return None

def tonline(soup):
    article = soup.find('div', attrs={'itemprop': 'articleBody'})
    paragraphs = article.find_all('p')
    content_list = []
    for paragraph in paragraphs:
        content_list.append(paragraph.get_text().strip())
    content = ' '.join(content_list)
    return content

def welt(soup):
    paragraph_div = soup.find('div', attrs={'class': 'c-article-text'})
    if paragraph_div is not None:
        paragraphs = paragraph_div.find_all('p')
        content_list = []
        for paragraph in paragraphs:
            if not paragraph.get_text().strip().startswith('Quelle:'):
                content_list.append(paragraph.get_text().strip())
        content = ' '.join(content_list)
        return content
    else:
        return None

def zdf(soup):
    if soup.article is not None:
        paragraphs = soup.article.find_all('p')
        content_list = []
        for paragraph in paragraphs:
            content_list.append(paragraph.get_text().strip())
        content = ' '.join(content_list)
        return content
    else:
        return None

def zeit(soup):
    if soup.article is not None:
        paragraphs = soup.article.find_all('p')
        content_list = []
        for paragraph in paragraphs:
            content_list.append(paragraph.get_text().strip())
        content = ' '.join(content_list)
        return content
    else:
        return None